@@ -111,11 +111,11 @@ class Bug(object):
             if bug_id is not None:
                 self.bug_id = bug_id.text
             if error == 'NotPermitted':
-                raise BugzillaNotPermitted(error, bug_id)
+                raise BugzillaNotPermitted(error, self.bug_id)
             if error == 'NotFound':
-                raise BugzillaNotFound(error, bug_id)
+                raise BugzillaNotFound(error, self.bug_id)
             if error == 'InvalidBugId':
-                raise BugzillaInvalidBugId(error, bug_id)
+                raise BugzillaInvalidBugId(error, self.bug_id)
             raise BugzillaError(error)
         self.cc_list = []
         self.groups = []
@@ -177,16 +177,11 @@ class Bug(object):
         '''
         Stores commend data within this object.
         '''
-        try:
-            bug_id = self.bug_id
-        except AttributeError:
-            bug_id = None
-
         who_elm = element.find('who')
         if who_elm is None:
             if not self.anonymous:
                 raise BugzillaNotPermitted(
-                    'Could not load author from bugzilla', bug_id
+                    'Could not load author from bugzilla', self.bug_id
                 )
             else:
                 who = ''
@@ -197,7 +192,7 @@ class Bug(object):
         if when_elm is None:
             if not self.anonymous:
                 raise BugzillaNotPermitted(
-                    'Could not load time of change from bugzilla', bug_id
+                    'Could not load time of change from bugzilla', self.bug_id
                 )
             else:
                 when = None
@@ -207,6 +202,7 @@ class Bug(object):
         self.comments.append({
             'who': who,
             'bug_when': when,
+            'private': (element.get('isprivate') == '1'),
             'thetext': element.find('thetext').text,
         })
 
@@ -222,6 +218,13 @@ class Bugzilla(WebScraper):
         )
         self.logger = logging.getLogger('suse.bugzilla')
 
+    def check_viewing_html(self):
+        '''
+        Checks whether the browser is in HTML viewing state.
+        '''
+        if not self.browser.viewing_html():
+            raise BugzillaLoginFailed('Failed to load bugzilla form')
+
     def check_login(self):
         '''
         Check whether we're logged in.
@@ -229,8 +232,7 @@ class Bugzilla(WebScraper):
         self.logger.info('Getting login page')
         self.request('index', GoAheadAndLogIn=1)
 
-        if not self.browser.viewing_html():
-            raise BugzillaLoginFailed('Failed to load bugzilla login form')
+        self.check_viewing_html()
 
         try:
             self.browser.find_link(text='Log\xc2\xa0out')
@@ -454,8 +456,8 @@ class Bugzilla(WebScraper):
         # Load the form
         self.logger.info('Loading bug page for %d', bugid)
         self.request('show_bug', id=bugid)
-        if not self.browser.viewing_html():
-            raise BugzillaUpdateError('Failed to load bugzilla form')
+
+        self.check_viewing_html()
 
         # Find link containing SR ids
         try:
@@ -490,8 +492,8 @@ class Bugzilla(WebScraper):
             raise BugzillaNotPermitted(
                 'You are not authorized to access bug #%d.' % bugid
             )
-        if not self.browser.viewing_html():
-            raise BugzillaUpdateError('Failed to load bugzilla form')
+
+        self.check_viewing_html()
 
         changes = False
 
@@ -516,7 +518,6 @@ class Bugzilla(WebScraper):
         # Whiteboard manipulations
         if whiteboard_add is not None or whiteboard_remove is not None:
             changes |= self._update_bug_whiteboard(
-                self.browser,
                 whiteboard_remove,
                 whiteboard_add
             )
@@ -533,11 +534,11 @@ class Bugzilla(WebScraper):
         if data.find('Changes submitted for') == -1:
             raise BugzillaUpdateError('Unknown error while submitting form')
 
-    def _update_bug_whiteboard(self, browser, remove, add):
+    def _update_bug_whiteboard(self, remove, add):
         '''
         Callback for changing bug whiteboard.
         '''
-        whiteboard = browser['status_whiteboard']
+        whiteboard = self.browser['status_whiteboard']
 
         if remove is not None and remove in whiteboard:
             whiteboard = whiteboard.replace(remove, '')
@@ -545,15 +546,13 @@ class Bugzilla(WebScraper):
         if add is not None and add not in whiteboard:
             whiteboard = '%s %s' % (whiteboard, add)
 
-        changes = (browser['status_whiteboard'] != whiteboard)
+        changes = (self.browser['status_whiteboard'] != whiteboard)
 
-        browser['status_whiteboard'] = whiteboard
+        self.browser['status_whiteboard'] = whiteboard
 
         # Do not add ourselves to cc
-        try:
-            browser['addselfcc'] = []
-        except ValueError:
-            pass
+        if 'addselfcc' in self.browser:
+            self.browser['addselfcc'] = []
 
         return changes
 
@@ -580,8 +579,7 @@ class APIBugzilla(Bugzilla):
         self.logger.info('Getting login page')
         self.request('index', GoAheadAndLogIn=1)
 
-        if not self.browser.viewing_html():
-            raise BugzillaLoginFailed('Failed to load bugzilla login form')
+        self.check_viewing_html()
 
         try:
             self.browser.find_link(text='Log\xc2\xa0out')
