@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright © 2012 - 2013 Michal Čihař <mcihar@suse.cz>
+# Copyright © 2012 - 2014 Michal Čihař <mcihar@suse.cz>
 #
 # This file is part of python-suseapi <https://github.com/nijel/python-suseapi>
 #
@@ -72,6 +72,9 @@ class SWAMP(object):
         self._client = Client(url)
 
     def _dict2map(self, dictdata):
+        '''
+        Converts Python dict into Apache map object.
+        '''
         result = self._client.factory.create('ns2:Map')
         for item in dictdata:
             mapitem = self._client.factory.create('ns2:mapItem')
@@ -302,7 +305,7 @@ class WebSWAMP(WebScraper):
         # Set some additional attributes
         self.browser.select_form('dataedit')
         self.browser['field_%s' % FIELD_ADDITIONAL_BUGZILLA] = \
-            ','.join(extra_bugs)
+            ','.join([str(bug) for bug in extra_bugs])
         self.browser['field_%s' % FIELD_PACKAGES] = ','.join(packages)
         if maintainer is not None:
             self.browser['field_%s' % FIELD_MAINTAINER] = maintainer
