@@ -1,4 +1,22 @@
-# -*- coding: UTF-8 -*-
+# -*- coding: utf-8 -*-
+#
+# Copyright © 2012 - 2014 Michal Čihař <mcihar@suse.cz>
+#
+# This file is part of python-suseapi <https://github.com/nijel/python-suseapi>
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
 '''
 Simple wrapper around LDAP module to allow easier search.
 '''
@@ -18,7 +36,7 @@ class UserInfo(CacherMixin):
     Class for LDAP access.
     '''
 
-    cache_key = 'userinfo-%s'
+    cache_key_template = 'userinfo-%s'
 
     searches = [
         '(mail={0}@novell.com)',
@@ -63,7 +81,7 @@ class UserInfo(CacherMixin):
         '''
         Returns user department.
         '''
-        department = self._cache_get(user)
+        department = self.cache_get(user)
         if department is not None:
             return department
 
@@ -89,7 +107,7 @@ class UserInfo(CacherMixin):
 
             department = self.fixup_department(dept)
 
-        self._cache_set(user, department)
+        self.cache_set(user, department)
 
         return department
 
